Documentation
¶
Index ¶
- func AddPlayerToLobby(player *models.Player, lobbyID string) error
- func Auth(c *fiber.Ctx) error
- func CreateLobby() int
- func CreatePlayer(c *websocket.Conn, uuid string) *models.Player
- func GenerateCarousel(c *spotify.Client) []string
- func HandleAddPlayerRequest(c *websocket.Conn)
- func HandleCreationRequest(c *websocket.Conn)
- func JoinLobby(c *websocket.Conn, lobby string)
- func PlayerWorker(c *websocket.Conn, p *models.Player, l *models.Lobby)
- type App
- type ClientData
- type Config
- type GuessData
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddPlayerToLobby ¶
Adds player to lobby with provided player id and lobby id
func CreateLobby ¶
func CreateLobby() int
Creates lobby and returns lobby id using bogo lobby algorithm
func GenerateCarousel ¶
func HandleAddPlayerRequest ¶
Reads player id and lobby id and assigns player to lobby if both player id and lobby exist
func HandleCreationRequest ¶
Handle websocket request for lobby creation
Types ¶
type ClientData ¶
Click to show internal directories.
Click to hide internal directories.